import env

from .core import Texts

path = env.get("TEXTS_PATH", None)

if not path:
    locales_path = env.get("LOCALES_PATH", "locales")
    locale = env.get("LOCALE")
    path = f"{locales_path}/{locale}.yml"

texts = Texts(path)



import yaml

Key = int | str


class Texts:
    def __init__(self, path: str) -> None:
        with open(path, encoding="utf8") as stream:
            raw_dict: dict = yaml.unsafe_load(stream)
        self.dict = {k: str(v) for k, v in raw_dict.items()}

    def get_words(self, key: Key) -> list[str]:
        text = self[key]
        return text.split()

    def __getitem__(self, item: Key) -> str:
        if item in self.dict:
            return str(self.dict[item])
        raise TextsKeyError(item)


class TextsKeyError(KeyError):
    def __init__(self, key: Key) -> None:
        self.key = key

    def __str__(self) -> str:
        return f"No text with key `{self.key}`"



from i_texts import texts

assert texts.dict == {1: "1", "a": "a", "words": "a b c", "ru": "русский"}
assert texts[1] == "1"
assert texts["a"] == "a"
assert texts.get_words("words") == ["a", "b", "c"]
